MpvLink

Struct MpvLink 

pub struct MpvLink { /* private fields */ }

Implementations

pub fn spawn_client() -> Result<Self, MpvLinkInitError>

Spawns a new child process and uses the input-ipc-client option to pass it a socket.

pub fn spawn_server(path: &Path) -> Result<Self, MpvLinkInitError>

Spawns a new child process and uses the input-ipc-server option to pass it a path where to create a socket.

pub fn connect(path: &Path) -> Result<Self, MpvLinkInitError>

Connects to an existing process spawned with input-ipc-server option by opening the socket.

pub fn set_nonblocking(&mut self, nonblocking: bool) -> Result<(), Error>

pub fn wait_read(&self, timeout: Option<Duration>) -> Result<(), Error>

Blocks until reading becomes available on self.stream().

If timeout is not None then returns Err(TimedOut) on timeout.

pub fn stream(&mut self) -> impl Read + Write + '_

Returns the RW stream for this link.

Panic

Panics is self has been deinitialized.

pub fn is_deinit(&self) -> bool

Returns true if self.deinit() has been called.

pub fn deinit(&mut self) -> Result<(), MpvLinkDeinitError>

Deinitializes self.

If self has been deinitialized returns Ok(()).